@@ -14,16 +14,17 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-
+#include <time.h>
+#include <stdlib.h>
 
 #include <qdir.h>
 #include <qfile.h>
 #include <qfileinfo.h>
 #include <qregexp.h>
+#include <qdir.h>
 
 #include <kfileitem.h>
 #include <kdebug.h>
@@ -47,7 +48,7 @@
 	QFile f("/tmp/debug");    \
 	f.open(IO_WriteOnly | IO_Append);     \
 	QTextStream stream( &f ); \
-  stream <<__FUNCTION__<<"(" <<__LINE__<<"): "; \
+  stream << "Pid:" << (int)getpid() << " " <<__FUNCTION__<<"(" <<__LINE__<<"): "; \
   stream << X << endl;      \
 	f.close();                \
 } while(0);
@@ -75,7 +76,11 @@ int kdemain( int argc, char **argv ){
 } // extern "C" 
 
 kio_krarcProtocol::kio_krarcProtocol(const QCString &pool_socket, const QCString &app_socket)
- : SlaveBase("kio_krarc", pool_socket, app_socket), archiveChanged(true), arcFile(0L),cpioReady(false){
+ : SlaveBase("kio_krarc", pool_socket, app_socket), archiveChanged(true), arcFile(0L),cpioReady(false),
+   password(QString::null) {
+  krConfig = new KConfig( "krusaderrc" );
+  krConfig->setGroup( "Dependencies" );
+   
   dirDict.setAutoDelete(true);
 
   arcTempDir = locateLocal("tmp",QString::null);
@@ -104,23 +109,43 @@ void kio_krarcProtocol::receivedData(KProcess*,char* buf,int len){
 
 void kio_krarcProtocol::mkdir(const KURL& url,int permissions){
   KRDEBUG(url.path());
+  
   setArcFile(url.path());
+  if( newArchiveURL && !initDirDict(url) ){ 
+    error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
+    return;
+  }
+  
   if( putCmd.isEmpty() ){
     error(ERR_UNSUPPORTED_ACTION,
     i18n("Creating directories is not supported with %1 archives").arg(arcType) );
     return;
   }
 
+  if( arcType == "arj" || arcType == "lha" )
+  {
+    QString arcDir = url.path().mid(arcFile->url().path().length());
+    if( arcDir.right(1) != "/") arcDir = arcDir+"/";
+    
+    if( dirDict.find( arcDir ) == 0 )
+        addNewDir( arcDir );
+    finished();
+    return;
+  }
+  
   //QString tmpDir = arcTempDir+url.path();
   QString arcDir  = findArcDirectory(url);
   QString tmpDir = arcTempDir + arcDir.mid(1) + url.path().mid(url.path().findRev("/")+1);
   if( tmpDir.right(1) != "/" ) tmpDir = tmpDir+"/";
     
-  if( permissions == -1 ) permissions = 0666; //set default permissions
+  if( permissions == -1 ) permissions = 0777; //set default permissions
   for( unsigned int i=arcTempDir.length();i<tmpDir.length(); i=tmpDir.find("/",i+1)){
-    ::mkdir(tmpDir.left(i).latin1(),permissions);
+    ::mkdir(tmpDir.left(i).local8Bit(),permissions);
   }
 
+  if( tmpDir.endsWith( "/" ) )
+    tmpDir.truncate( tmpDir.length() - 1 );
+       
 	// pack the directory
 	KShellProcess proc;
 	proc << putCmd << "\""+arcFile->url().path()+"\" " << "\""+tmpDir.mid(arcTempDir.length())+"\"";
@@ -138,6 +163,11 @@ void kio_krarcProtocol::mkdir(const KURL& url,int permissions){
 void kio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool resume){
   KRDEBUG(url.path());
   setArcFile(url.path());
+  if( newArchiveURL && !initDirDict(url) ){ 
+    error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
+    return;
+  }
+  
   if( putCmd.isEmpty() ){
     error(ERR_UNSUPPORTED_ACTION,
     i18n("Writing to %1 archives is not supported").arg(arcType) );
@@ -157,7 +187,7 @@ void kio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool
 	}
 	int fd;
 	if ( resume ) {
-		fd = KDE_open( tmpFile.latin1(), O_RDWR );  // append if resuming
+		fd = KDE_open( tmpFile.local8Bit(), O_RDWR );  // append if resuming
 		KDE_lseek(fd, 0, SEEK_END); // Seek to end
 	} else {
 		// WABA: Make sure that we keep writing permissions ourselves,
@@ -168,7 +198,7 @@ void kio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool
 		else
 			initialMode = 0666;
 
-		fd = KDE_open(tmpFile.latin1(), O_CREAT | O_TRUNC | O_WRONLY, initialMode);
+		fd = KDE_open(tmpFile.local8Bit(), O_CREAT | O_TRUNC | O_WRONLY, initialMode);
 	}
   QByteArray buffer;
 	int readResult;
@@ -192,8 +222,15 @@ void kio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool
 }
 
 void kio_krarcProtocol::get(const KURL& url ){
+  bool isArjGet = false;
   KRDEBUG(url.path());
+  
   if( !setArcFile(url.path()) ) return;
+  if( newArchiveURL && !initDirDict(url) ){ 
+    error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
+    return;
+  }
+  
   if( getCmd.isEmpty() ){
     error(ERR_UNSUPPORTED_ACTION,
     i18n("Retrieving data from %1 archives is not supported").arg(arcType) );
@@ -220,6 +257,12 @@ void kio_krarcProtocol::get(const KURL& url ){
 	KShellProcess proc;
   if( cpioReady ){
     proc << getCmd << arcTempDir+"contents.cpio " << "\"*"+file+"\"";
+  } else if(  arcType == "arj" || arcType == "ace" ) {
+    proc << getCmd << "\""+arcFile->url().path()+"\" " << "\""+file+"\"";
+    if( arcType == "ace" && QFile( "/dev/ptmx" ).exists() ) // Don't remove, unace crashes if missing!!!
+      proc << "<" << "/dev/ptmx"; 
+    file = url.fileName();
+    isArjGet = true;
   } else {
     // Determine the mimetype of the file to be retrieved, and emit it.
     // This is mandatory in all slaves (for KRun/BrowserRun to work).
@@ -233,9 +276,9 @@ void kio_krarcProtocol::get(const KURL& url ){
   // change the working directory to our arcTempDir
   QDir::setCurrent(arcTempDir);
   proc.start(KProcess::Block,KProcess::AllOutput);
-  if( cpioReady ){
+  if( cpioReady || isArjGet ){
     // the follwing block is ripped from KDE file KIO::Slave
-    // $Id: krarc.cpp,v 1.11 2003/11/12 16:43:42 ckarai Exp $
+    // $Id: krarc.cpp,v 1.28 2004/09/28 18:43:25 ckarai Exp $
     QCString _path( QFile::encodeName(arcTempDir+file) );
     KDE_struct_stat buff;
     if( KDE_lstat( _path.data(), &buff ) == -1 ) {
@@ -308,6 +351,9 @@ void kio_krarcProtocol::get(const KURL& url ){
     close( fd );
     processedSize( buff.st_size );
     finished();
+    
+    if( isArjGet )
+      QFile(arcTempDir+file).remove();
     return;
   }
   // send empty buffer to mark EOF
@@ -317,15 +363,23 @@ void kio_krarcProtocol::get(const KURL& url ){
 
 void kio_krarcProtocol::del(KURL const & url, bool isFile){
   KRDEBUG(url.path());
+  
   setArcFile(url.path());
+  if( newArchiveURL && !initDirDict(url) ){ 
+    error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
+    return;
+  }
+  
   if( delCmd.isEmpty() ){
     error(ERR_UNSUPPORTED_ACTION,
     i18n("Deleting files from %1 archives is not supported").arg(arcType) );
     return;
   }
 	if( !findFileEntry(url) ){
-		error(KIO::ERR_DOES_NOT_EXIST,url.path());
-		return;
+        if( ( arcType != "arj" && arcType != "lha" ) || isFile ) {
+			error(KIO::ERR_DOES_NOT_EXIST,url.path());
+			return;
+		}
 	}
 
 	QString file = url.path().mid(arcFile->url().path().length()+1);
@@ -341,26 +395,31 @@ void kio_krarcProtocol::del(KURL const & url, bool isFile){
 	finished();
 }
 
-void kio_krarcProtocol::stat( const KURL & url ){
+void kio_krarcProtocol::stat( const KURL & url ){  
   KRDEBUG(url.path());
   if( !setArcFile(url.path()) ) return;
+  if( newArchiveURL && !initDirDict(url) ){ 
+    error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
+    return;
+  }
+  
   if( listCmd.isEmpty() ){
     error(ERR_UNSUPPORTED_ACTION,
     i18n("Accessing files is not supported with the %1 archives").arg(arcType) );
     return;
-  }
-  QString path = url.path();
+  }    
+  QString path = url.path(-1);
 	KURL newUrl = url;
 	
   // but treat the archive itself as the archive root
-	if( path == arcFile->url().path() ){
+	if( path == arcFile->url().path(-1) ){
     newUrl.setPath(path+"/");
 		path = newUrl.path();
 	}
 	// we might be stating a real file
 	if( QFileInfo(path).exists() ){
 		KDE_struct_stat buff;
-    KDE_stat( path.latin1(), &buff );
+    KDE_stat( path.local8Bit(), &buff );
 		QString mime = KMimeType::findByPath(path,buff.st_mode)->name();
 		statEntry(KFileItem(path,mime,buff.st_mode).entry());
     finished();
@@ -374,6 +433,61 @@ void kio_krarcProtocol::stat( const KURL & url ){
 	else error(KIO::ERR_DOES_NOT_EXIST,path);
 }
 
+void kio_krarcProtocol::copy (const KURL &url, const KURL &dest, int, bool overwrite) {
+  KRDEBUG(url.path());
+  
+  if( dest.isLocalFile() )
+    do
+    {
+      if( url.fileName() != dest.fileName() )
+        break;
+   
+      //the file exists and we don't want to overwrite
+      if ((!overwrite) && ( QFile( dest.path() ).exists() ) )
+      {
+         error(ERR_FILE_ALREADY_EXIST, QFile::encodeName(dest.path()) );
+         return;
+      };
+      
+      setArcFile(url.path());
+      if( newArchiveURL && !initDirDict(url) ){ 
+        error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
+        return;
+      }
+      
+      UDSEntry* entry = findFileEntry(url);
+      if( copyCmd.isEmpty() || !entry )
+        break;
+
+      QString file = url.path().mid(arcFile->url().path().length()+1);
+      
+      QString destDir = dest.path( -1 );
+      if( !QDir( destDir ).exists() )
+      {
+        int ndx = destDir.findRev( '/' );
+         if( ndx != -1 )
+          destDir.truncate( ndx+1 );
+      }
+      
+      QDir::setCurrent( destDir.local8Bit() );
+
+      KShellProcess proc;
+      proc << copyCmd << "\""+arcFile->url().path()+"\" " << "\""+file+"\"";
+      if( arcType == "ace" && QFile( "/dev/ptmx" ).exists() ) // Don't remove, unace crashes if missing!!!
+        proc << "<" << "/dev/ptmx"; 
+
+      infoMessage(i18n("Unpacking %1 ...").arg( url.fileName() ) );
+      proc.start(KProcess::Block);
+      
+      processedSize( KFileItem(*entry,url).size() );
+      finished();
+      QDir::setCurrent( "/" ); /* for being able to umount devices after copying*/
+      return;
+    }while( 0 );
+
+  error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_COPY));
+}
+
 void kio_krarcProtocol::listDir(const KURL& url){
   KRDEBUG(url.path());
   if( !setArcFile(url.path()) ) return;
@@ -417,13 +531,17 @@ void kio_krarcProtocol::listDir(const KURL& url){
 }
 
 bool kio_krarcProtocol::setArcFile(const QString& path){
+	time_t currTime = time( 0 );
 	archiveChanged = true;
+	newArchiveURL = true;
 	// is the file already set ?
-	if( arcFile && arcFile->url().path() == path.left(arcFile->url().path().length()) ){
+	if( arcFile && arcFile->url().path(-1) == path.left(arcFile->url().path(-1).length()) ){
+		newArchiveURL = false;        
 		// Has it changed ?
 		KFileItem* newArcFile = new KFileItem(arcFile->url(),QString::null,0);
-		if( newArcFile->time(UDS_MODIFICATION_TIME) != arcFile->time(UDS_MODIFICATION_TIME) ){
-      delete arcFile;
+		if( !newArcFile->cmp( *arcFile ) ){
+			delete arcFile;
+			password = QString::null;
 			arcFile = newArcFile;
 		}
 		else { // same old file
@@ -434,6 +552,7 @@ bool kio_krarcProtocol::setArcFile(const QString& path){
 	else {// it's a new file...
 		if( arcFile ){
 			delete arcFile;
+      password = QString::null;
 			arcFile = 0L;
 		}
 		QString newPath = path;
@@ -450,27 +569,48 @@ bool kio_krarcProtocol::setArcFile(const QString& path){
        return false; // file not found
     }
 	}
+  
+  /* FIX: file change can only be detected if the timestamp between the two consequent 
+     changes is more than 1s. If the archive is continuously changing (check: move files 
+     inside the archive), krarc may erronously think, that the archive file is unchanged, 
+     because the timestamp is the same as the previous one. This situation can only occur
+     if the modification time equals with the current time. While this condition is true,
+     we can say, that the archive is changing, so content reread is always necessary 
+     during that period. */
+  if( archiveChanging )
+    archiveChanged = true;
+  archiveChanging = ( currTime == arcFile->time( UDS_MODIFICATION_TIME ) );
+  
   arcType = arcFile->mimetype();
   arcType = arcType.mid(arcType.findRev("-")+1);
-  arcPath = "\""+arcFile->url().path()+"\"";
+  
+  if( arcType == "jar" )
+    arcType = "zip";
+  
+  arcPath = "\""+arcFile->url().path(-1)+"\"";
   arcPath.replace(QRegExp(" "),"\\ ");
   return initArcParameters();
 }
 
-bool kio_krarcProtocol::initDirDict(const KURL&, bool forced){
+bool kio_krarcProtocol::initDirDict(const KURL&url, bool forced){
 	// set the archive location
 	//if( !setArcFile(url.path()) ) return false;
 	// no need to rescan the archive if it's not changed
 	if( !archiveChanged && !forced ) return true;
+
+	setArcFile( url.path() );   /* if the archive was changed refresh the file information */
+	
 	// write the temp file
 	KShellProcess proc;
-	KTempFile temp("krarc","tmp");
+	KTempFile temp( QString::null, "tmp" );
 	temp.setAutoDelete(true);
-
-	proc << listCmd << "\""+arcFile->url().path()+"\"" <<" > " << temp.name();
-	proc.start(KProcess::Block);
-	if( !proc.normalExit() || !proc.exitStatus() == 0 )	return false;
-
+	if( arcType != "bzip2" ){
+		proc << listCmd << "\""+arcFile->url().path(-1)+"\"" <<" > " << temp.name();
+		if( arcType == "ace" && QFile( "/dev/ptmx" ).exists() ) // Don't remove, unace crashes if missing!!!
+			proc << "<" << "/dev/ptmx";
+		proc.start(KProcess::Block);
+		if( !proc.normalExit() || !proc.exitStatus() == 0 )	return false;
+  }
 	// clear the dir dictionary
 	dirDict.clear();
 
@@ -493,6 +633,12 @@ bool kio_krarcProtocol::initDirDict(const KURL&, bool forced){
 
 	root->append(entry);
 
+	if( arcType == "bzip2" ){
+		KRDEBUG("Got me here...");
+		parseLine(0,"",temp.file());
+		return true;
+	}
+
 	// parse the temp file
 	temp.file()->open(IO_ReadOnly);
 	char buf[1000];
@@ -500,22 +646,42 @@ bool kio_krarcProtocol::initDirDict(const KURL&, bool forced){
 
 	int lineNo = 0;
   // the rar list is started with a ------ line.
-  if(arcType == "rar"){
+  if(arcType == "rar" || arcType == "arj" || arcType == "lha" ){
     while(temp.file()->readLine(buf,1000) != -1){
       line = QString::fromLocal8Bit(buf);
-      if( line.startsWith("-----------") ) break;
+      if( line.startsWith("----------") ) break;
     }
   } 
 	while(temp.file()->readLine(buf,1000) != -1){
 		line = QString::fromLocal8Bit(buf);
     if( arcType == "rar" ) {
        // the rar list is ended with a ------ line.
-       if( line.startsWith("-----------") ) break;
+       if( line.startsWith("----------") ) break;
        else{
          temp.file()->readLine(buf,1000);
          line = line+QString::fromLocal8Bit(buf);
        }
     }
+    if( arcType == "ace" ) {
+       // the ace list begins with a number.
+       if( !line[0].isDigit() ) continue;
+    }
+    if( arcType == "arj" ) {
+       // the arj list is ended with a ------ line.
+       if( line.startsWith("----------") ) break;
+       else{
+         temp.file()->readLine(buf,1000);
+         line = line+QString::fromLocal8Bit(buf);
+         temp.file()->readLine(buf,1000);
+         line = line+QString::fromLocal8Bit(buf);
+         temp.file()->readLine(buf,1000);
+         line = line+QString::fromLocal8Bit(buf);
+       }
+    }
+    if( arcType == "lha" ) {
+       // the arj list is ended with a ------ line.
+       if( line.startsWith("----------") ) break;
+    }
     parseLine(lineNo++,line.stripWhiteSpace(),temp.file());
 	}
   // close and delete our file
@@ -548,7 +714,7 @@ UDSEntry* kio_krarcProtocol::findFileEntry(const KURL& url){
 		return 0;
 	}
 	QString name = url.path();
-	if( name.right(1) == "/" && arcDir == "/" ) name = "."; // the "/" case
+	if( arcFile->url().path(-1) == url.path(-1) ) name = "."; // the "/" case
 	else{
 		if( name.right(1) == "/" ) name.truncate(name.length()-1);
 		name = name.mid(name.findRev("/")+1);
@@ -648,7 +814,7 @@ UDSEntryList* kio_krarcProtocol::addNewDir(QString path){
   return dir;
 }
 
-void kio_krarcProtocol::parseLine(int, QString line, QFile*){
+void kio_krarcProtocol::parseLine(int lineNo, QString line, QFile*){
   UDSEntryList* dir;
 	UDSEntry entry;
 	UDSAtom atom;
@@ -665,8 +831,6 @@ void kio_krarcProtocol::parseLine(int, QString line, QFile*){
   if(arcType == "zip"){
     // permissions
     perm = nextWord(line);
-    if(perm.length() != 10) perm = (perm.at(0)=='d')? "drwxr-xr-x" : "-rw-r--r--" ;
-    mode = parsePermString(perm);
     // ignore the next 2 fields
     nextWord(line); nextWord(line);
     // size
@@ -680,6 +844,10 @@ void kio_krarcProtocol::parseLine(int, QString line, QFile*){
     time = QDateTime(qdate,qtime).toTime_t();
     // full name
     fullName = nextWord(line,'\n');
+    
+    if(perm.length() != 10) 
+      perm = (perm.at(0)=='d' || fullName.endsWith( "/" )) ? "drwxr-xr-x" : "-rw-r--r--" ;
+    mode = parsePermString(perm);
   }
   if(arcType == "rar"){
     // full name
@@ -690,10 +858,46 @@ void kio_krarcProtocol::parseLine(int, QString line, QFile*){
     nextWord(line); nextWord(line);
     // date & time
     QString d = nextWord(line);
-    QDate qdate(d.mid(6,2).toInt(),d.mid(3,2).toInt(),d.mid(0,2).toInt());
-    if( qdate.year() < 1930 ) qdate.addYears(100);
+    int year = 1900 + d.mid(6,2).toInt();
+    if( year < 1930 ) year+=100;
+    QDate qdate( year, d.mid(3,2).toInt(), d.mid(0,2).toInt() );
     QString t = nextWord(line);
-    QTime qtime(t.mid(0,2).toInt(),t.mid(4,2).toInt(),0);
+    QTime qtime(t.mid(0,2).toInt(),t.mid(3,2).toInt(),0);
+    time = QDateTime(qdate,qtime).toTime_t();    
+    // permissions
+    perm = nextWord(line);
+    
+    if( perm.length() == 7 ) // windows rar permission format
+    {
+      bool isDir  = ( perm.at(1).lower() == 'd' );
+      bool isReadOnly = ( perm.at(2).lower() == 'r' );
+      
+      perm = isDir ? "drwxr-xr-x" : "-rw-r--r--";
+      
+      if( isReadOnly )
+        perm.at( 2 ) = '-';
+    }        
+    
+    if(perm.length() != 10) perm = (perm.at(0)=='d')? "drwxr-xr-x" : "-rw-r--r--" ;    
+    mode = parsePermString(perm);
+  }
+  if(arcType == "arj"){
+    nextWord(line);
+    // full name
+    fullName = nextWord(line,'\n');
+    // ignore the next 2 fields
+    nextWord(line); nextWord(line);
+    // size
+    size = nextWord(line).toLong();
+    // ignore the next 2 fields
+    nextWord(line); nextWord(line);
+    // date & time
+    QString d = nextWord(line);
+    int year = 1900 + d.mid(0,2).toInt();
+    if( year < 1930 ) year+=100;
+    QDate qdate( year, d.mid(3,2).toInt(), d.mid(6,2).toInt() );
+    QString t = nextWord(line);
+    QTime qtime(t.mid(0,2).toInt(),t.mid(3,2).toInt(),0);
     time = QDateTime(qdate,qtime).toTime_t();    
     // permissions
     perm = nextWord(line);
@@ -716,12 +920,78 @@ void kio_krarcProtocol::parseLine(int, QString line, QFile*){
     group = nextWord(line);
     // symlink destination
     if( S_ISLNK(mode) ){
-      // ignore the next 3 fields
-      nextWord(line); nextWord(line); nextWord(line);
-      symlinkDest = nextWord(line);
+			// ignore the next 3 fields
+			nextWord(line); nextWord(line); nextWord(line);
+			symlinkDest = nextWord(line);
     }
   }
-
+  if( arcType == "gzip" ){
+		if( !lineNo ) return; //ignore the first line
+		// first field is uncompressed size - ignore it
+    nextWord(line);
+    // size
+    size = nextWord(line).toULong();
+    // ignore the next field
+    nextWord(line);
+    // full name
+    fullName = nextWord(line);
+    fullName = fullName.mid(fullName.findRev("/")+1);
+  }
+  if( arcType == "bzip2" ){
+		// There is no way to list bzip2 files, so we take our information from
+    // the archive itself...
+    fullName = arcFile->name();
+    if( fullName.endsWith("bz2") ) fullName.truncate(fullName.length()-4);
+    mode = arcFile->mode();
+    size = arcFile->size();
+  }
+  if(arcType == "lha"){
+    // permissions
+    perm = nextWord(line);
+    if(perm.length() != 10) perm = (perm.at(0)=='d')? "drwxr-xr-x" : "-rw-r--r--" ;
+    mode = parsePermString(perm);
+    // ignore the next field
+    nextWord(line);
+    // size
+    size = nextWord(line).toLong();
+    // ignore the next field
+    nextWord(line);
+    // date & time
+    int month = (QStringList::split(',', "Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec")).findIndex( nextWord(line) ) + 1;
+    int day = nextWord(line).toInt();
+    int year = QDate::currentDate().year();
+    QString third = nextWord(line);
+    QTime qtime;
+    
+    if( third.contains(":" ) )
+      qtime = QTime::fromString( third );
+    else
+      year = third.toInt();
+    
+    QDate qdate(year, month, day );
+    
+    time = QDateTime(qdate, qtime).toTime_t();    
+    // full name
+    fullName = nextWord(line,'\n');
+  }
+  if(arcType == "ace"){
+    // date & time
+    QString d = nextWord(line);
+    int year = 1900 + d.mid(6,2).toInt();
+    if( year < 1930 ) year+=100;
+    QDate qdate( year, d.mid(3,2).toInt(), d.mid(0,2).toInt() );
+    QString t = nextWord(line);
+    QTime qtime(t.mid(0,2).toInt(),t.mid(3,2).toInt(),0);
+    time = QDateTime(qdate,qtime).toTime_t();    
+    // ignore the next field
+    nextWord(line);
+    // size
+    size = nextWord(line).toLong();
+    // ignore the next field
+    nextWord(line);
+    // full name
+    fullName = nextWord(line,'\n');
+  }
   if( fullName.right(1) == "/" ) fullName = fullName.left(fullName.length()-1);
   if( !fullName.startsWith("/") ) fullName = "/"+fullName;
   QString path = fullName.left(fullName.findRev("/")+1);
@@ -760,35 +1030,126 @@ void kio_krarcProtocol::parseLine(int, QString line, QFile*){
     if(dirDict.find(fullName) == 0)
       dirDict.insert(fullName,new UDSEntryList());
     else
+    {
+      // try to overwrite an existing entry
+      UDSEntryList::iterator entryIt;
+      UDSEntry::iterator atomIt;
+      
+      for ( entryIt = dir->begin(); entryIt != dir->end(); ++entryIt )
+        for( atomIt = (*entryIt).begin(); atomIt != (*entryIt).end(); ++atomIt )
+          if( (*atomIt).m_uds == UDS_NAME )
+            if((*atomIt).m_str == name)
+            {
+              for( atomIt = (*entryIt).begin(); atomIt != (*entryIt).end(); ++atomIt )
+              {
+                switch( (*atomIt).m_uds )
+                {
+                case UDS_MODIFICATION_TIME:
+                  (*atomIt).m_long = time;
+                  break;
+                case UDS_ACCESS:
+                  (*atomIt).m_long = mode & 07777;
+                  break;
+                }
+              }
+              return;
+            }
       return; // there is alreay an entry for this directory
+    }
   }
   
   dir->append(entry);
 }
 
 bool kio_krarcProtocol::initArcParameters(){
+	KRDEBUG("arcType: "<<arcType);
+
   if(arcType == "zip"){
-    cmd = "unzip";
-    listCmd = "unzip -ZTs-z-t-h ";
-    getCmd  = "unzip -p ";
-    delCmd  = "zip -d ";
-    putCmd  = "zip -ry ";
+    cmd     = fullPathName( "unzip" );
+    listCmd = fullPathName( "unzip" ) + " -ZTs-z-t-h ";
+    getCmd  = fullPathName( "unzip" ) + " -p ";
+    copyCmd = fullPathName( "unzip" ) + " -jo ";
+    
+    if( KStandardDirs::findExe( "zip" ).isEmpty() ) {
+      delCmd  = QString::null;
+      putCmd  = QString::null;
+    } else {
+      delCmd  = fullPathName( "zip" ) + " -d ";
+      putCmd  = fullPathName( "zip" ) + " -ry ";
+    }
+
+    if( !getPassword().isEmpty() )
+    {
+      getCmd += "-P '"+password+"' ";
+      copyCmd += "-P '"+password+"' ";
+      putCmd += "-P '"+password+"' ";
+    }
   } else if (arcType == "rar"){
-    cmd = "unrar" ;
-    listCmd = "unrar -c- v ";
-    getCmd  = "unrar p -ierr -idp -c- -y ";
-    delCmd  = "rar d ";
-    putCmd  = "rar -r a ";
+    if( KStandardDirs::findExe( "rar" ).isEmpty() )
+    {
+      cmd     = fullPathName( "unrar" );
+      listCmd = fullPathName( "unrar" ) + " -c- v ";
+      getCmd  = fullPathName( "unrar" ) + " p -ierr -idp -c- -y ";
+      copyCmd = fullPathName( "unrar" ) + " e -y ";
+      delCmd  = QString::null;
+      putCmd  = QString::null;
+    }
+    else
+    {
+      cmd     = fullPathName( "rar" );
+      listCmd = fullPathName( "rar" ) + " -c- v ";
+      getCmd  = fullPathName( "rar" ) + " p -ierr -idp -c- -y ";
+      copyCmd = fullPathName( "rar" ) + " e -y ";
+      delCmd  = fullPathName( "rar" ) + " d ";
+      putCmd  = fullPathName( "rar" ) + " -r a ";
+    }
   } else if(arcType == "rpm"){
-    cmd = "rpm";
-    listCmd = "rpm --dump -lpq ";
-    getCmd  = "cpio --force-local --no-absolute-filenames -ivdF";
+    cmd     = fullPathName( "rpm" );
+    listCmd = fullPathName( "rpm" ) + " --dump -lpq ";
+    getCmd  = fullPathName( "cpio" ) + " --force-local --no-absolute-filenames -ivdF";
+    delCmd  = QString::null;
+    putCmd  = QString::null;
+    copyCmd = QString::null;
+  } else if(arcType == "gzip"){
+    cmd     = fullPathName( "gzip" );
+    listCmd = fullPathName( "gzip" ) + " -l";
+    getCmd  = fullPathName( "gzip" ) + " -dc";
+    copyCmd = QString::null;
+    delCmd  = QString::null;
+    putCmd  = QString::null;
+  } else if(arcType == "bzip2"){
+    cmd     = fullPathName( "bzip2" );
+    listCmd = fullPathName( "bzip2" );
+    getCmd  = fullPathName( "bzip2" ) + " -dc";
+    copyCmd = QString::null;
+    delCmd  = QString::null;
+    putCmd  = QString::null;
+  } else if(arcType == "arj"){
+    cmd     = fullPathName( "arj" );
+    listCmd = fullPathName( "arj" ) + " v ";
+    getCmd  = fullPathName( "arj" ) + " -jyo e ";
+    copyCmd = fullPathName( "arj" ) + " -jyo e ";
+    delCmd  = fullPathName( "arj" ) + " d ";
+    putCmd  = fullPathName( "arj" ) + " -r a ";
+  } else if(arcType == "lha"){
+    cmd     = fullPathName( "lha" );
+    listCmd = fullPathName( "lha" ) + " l ";
+    getCmd  = fullPathName( "lha" ) + " pq ";
+    copyCmd = fullPathName( "lha" ) + " eif ";
+    delCmd  = fullPathName( "lha" ) + " d ";
+    putCmd  = fullPathName( "lha" ) + " a ";
+  } else if(arcType == "ace"){
+    cmd     = fullPathName( "unace" );
+    listCmd = fullPathName( "unace" ) + " v";
+    getCmd  = fullPathName( "unace" ) + " e -o ";
+    copyCmd = fullPathName( "unace" ) + " e -o ";
     delCmd  = QString::null;
     putCmd  = QString::null;
   } else {
     cmd     = QString::null;
     listCmd = QString::null;
     getCmd  = QString::null;
+    copyCmd = QString::null;
     delCmd  = QString::null;
     putCmd  = QString::null;
   }
@@ -797,9 +1158,57 @@ bool kio_krarcProtocol::initArcParameters(){
     error( KIO::ERR_CANNOT_LAUNCH_PROCESS,
     cmd+
     i18n("\nMake sure that the %1 binary are installed properly on your system.").arg(cmd));
+    KRDEBUG("Failed to find cmd: " << cmd);
     return false;
   }
   return true;
 }
 
+
+QString kio_krarcProtocol::getPassword() {    
+  if( !password.isNull() )
+    return password;
+
+  QFile zipFile( arcFile->url().path() );
+  if( zipFile.open( IO_ReadOnly ) )
+  {
+    char zipHeader[8];
+
+    if( zipFile.readBlock( zipHeader, 8 ) != 8 )
+      return (password = "" );
+
+    if( zipHeader[0] != 'P' || zipHeader[1] != 'K' || zipHeader[2] != 3 || zipHeader[3] != 4 )
+      return (password = "" );
+    
+    if( ! ( zipHeader[6] & 1 ) )  /* not encrypted */
+      return (password = "" );
+        
+    KIO::AuthInfo authInfo;
+    authInfo.caption= i18n( "Zip Password Dialog" );
+    authInfo.username= "zipfile";
+    authInfo.readOnly = true;
+    authInfo.keepPassword = true;
+    authInfo.verifyPath = true;
+    authInfo.url = KURL::fromPathOrURL( arcFile->url().path() );
+
+    if( checkCachedAuthentication( authInfo ) )
+      return ( password = authInfo.password );
+
+    if ( openPassDlg( authInfo ) )
+      return ( password = authInfo.password );
+  }
+
+  return (password = "" );
+}
+
+QString kio_krarcProtocol::fullPathName( QString name )
+{
+  QString supposedName = krConfig->readEntry( name, name );
+  if( supposedName.isEmpty() )
+    supposedName = name;
+  supposedName.replace( "\\", "\\\\" );
+  supposedName.replace( " ", "\\ " );  
+  return supposedName;
+}
+
 #include "krarc.moc"
