@@ -4,6 +4,8 @@
 #include <ksqueezedtextlabel.h>
 
 class QMouseEvent;
+class QDropEvent;
+class QDragEnterEvent;
 
 /**
 This class overloads KSqueezedTextLabel and simply adds a clicked signal,
@@ -15,11 +17,19 @@ Q_OBJECT
     KrSqueezedTextLabel(QWidget *parent = 0, const char *name = 0);
     ~KrSqueezedTextLabel();
 
+    void enableDrops( bool flag );
+
   signals:
     void clicked(); /**< emitted when someone clicks on the label */
+    void dropped(QDropEvent *); /**< emitted when someone drops URL onto the label */
 
   protected:
     virtual void mousePressEvent(QMouseEvent *e);
+    virtual void dropEvent(QDropEvent *e);
+    virtual void dragEnterEvent(QDragEnterEvent *e);
+
+  private:
+    bool  acceptDrops;
 };
 
 #endif
