@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Apr 18 2002
     copyright            : (C) 2002 by Shie Erlich & Rafi Yanai
-    email                : 
+    email                :
  ***************************************************************************/
 
 /***************************************************************************
@@ -32,22 +32,39 @@
 #include <kdebug.h>
 #include <klargefile.h>
 #include <khtml_part.h>
+#include <kprocess.h>
+#include <kfileitem.h>
 // Krusader includes
 #include "krviewer.h"
 #include "../krusader.h"
-
+#include "../defaults.h"
 
 KrViewer::KrViewer(QWidget *parent, const char *name ) :
-  KParts::MainWindow(parent,name), manager(this,this){
+  KParts::MainWindow(parent,name), manager(this,this), normalExit(false){
+
   //setWFlags(WType_TopLevel | WDestructiveClose);
   setXMLFile("krviewerui.rc");
   setHelpMenuEnabled(false);
+  
+  // KDE HACK START: Viewer fails to resize at maximized mode
+  int scnum = QApplication::desktop()->screenNumber(parentWidget());
+  QRect desk = QApplication::desktop()->screenGeometry(scnum);
+  KGlobal::config()->setGroup( "KrViewerWindow" );
+  QSize size( KGlobal::config()->readNumEntry( QString::fromLatin1("Width %1").arg(desk.width()), 0 ),
+              KGlobal::config()->readNumEntry( QString::fromLatin1("Height %1").arg(desk.height()), 0 ) );
+  if( size.width() > desk.width() )
+    KGlobal::config()->writeEntry( QString::fromLatin1("Width %1").arg(desk.width()), desk.width() );
+  if( size.height() > desk.height() )
+    KGlobal::config()->writeEntry( QString::fromLatin1("Height %1").arg(desk.height()), desk.height() );
+  // KDE HACK END
+    
   setAutoSaveSettings("KrViewerWindow",true);
   tmpFile.setAutoDelete(true);
   hex_part=generic_part=text_part=editor_part=0L;
 
   connect(&manager,SIGNAL(activePartChanged(KParts::Part*)),
           this,SLOT(createGUI(KParts::Part*)));
+  
 
   viewerMenu = new QPopupMenu( this );
   viewerMenu->insertItem( i18n("&Generic viewer"), this, SLOT(viewGeneric()), CTRL+Key_G,1 );
@@ -62,6 +79,12 @@ KrViewer::KrViewer(QWidget *parent, const char *name ) :
 }
 
 KrViewer::~KrViewer(){
+	if (!normalExit && editor_part && editor_part->isModified() ) {
+    	switch ( KMessageBox::warningYesNo( this, i18n("The editor is about to close. Do you want to save your changes?")) ) {
+  			case KMessageBox::Yes :
+    			((KParts::ReadWritePart*)editor_part)->save();
+  			}
+	}
 	//kdDebug() << "KrViewer killed" << endl;
 }
 
@@ -70,6 +93,13 @@ KParts::Part* KrViewer::getPart(KURL url, QString mimetype ,bool readOnly, bool
   KLibFactory  *factory = 0;
   KTrader::OfferList offers = KTrader::self()->query(mimetype);
   QString type = (readOnly ? "KParts::ReadOnlyPart" : "KParts::ReadWritePart");
+  
+  if( create )
+  {
+    KFileItem file( KFileItem::Unknown, KFileItem::Unknown, url );
+    if( file.isReadable() )
+      create = false;
+  }
 
   // in theory, we only care about the first one.. but let's try all
   // offers just in case the first can't be loaded for some reason
@@ -79,16 +109,40 @@ KParts::Part* KrViewer::getPart(KURL url, QString mimetype ,bool readOnly, bool
     // we now know that our offer can handle mimetype and is a part.
     // since it is a part, it must also have a library... let's try to
     // load that now
-    factory = KLibLoader::self()->factory( ptr->library().latin1() );
-    if (factory) {
-      part = static_cast<KParts::Part *>(factory->create(this,
-                           ptr->name().latin1(), type.latin1() ));
-      if( part )
-        if( ((KParts::ReadOnlyPart*)part)->openURL( url ) || create ) break;
-        else {
-          delete part;
-          part = 0L;
+
+    QStringList args;
+    QVariant argsProp = ptr->property( "X-KDE-BrowserView-Args" );
+    if ( argsProp.isValid() )
+    {
+      QString argStr = argsProp.toString();
+      args = QStringList::split( " ", argStr );
+    }
+    
+    QVariant prop = ptr->property( "X-KDE-BrowserView-AllowAsDefault" );
+
+    if ( !prop.isValid() || prop.toBool() ) // defaults to true
+    {
+      factory = KLibLoader::self()->factory( ptr->library().latin1() );
+      if (factory) {
+        part = static_cast<KParts::Part *>(factory->create(this,
+                             ptr->name().latin1(), type.latin1(), args ));
+        if( part )
+        {
+          if( !create )
+          {
+            if( ((KParts::ReadOnlyPart*)part)->openURL( url ) ) break;
+            else {
+              delete part;
+              part = 0L;
+            }
+          }
+          else
+          {
+            ((KParts::ReadWritePart*)part)->saveAs( url );
+            break;
+          }
         }
+      }
     }
   }
   return part;
@@ -144,6 +198,21 @@ void KrViewer::view(KURL url){
 }
 
 void KrViewer::edit(KURL url, bool create){
+  krConfig->setGroup( "General" );
+  QString edit = krConfig->readEntry( "Editor", _Editor );
+
+  if ( edit != "internal editor" ) {
+    KProcess proc;
+    // if the file is local, pass a normal path and not a url. this solves
+	 // the problem for editors that aren't url-aware
+	 if (url.isLocalFile())
+	 	proc << QStringList::split(' ', edit) << url.path();
+	 else proc << QStringList::split(' ', edit) << url.prettyURL();
+	 if ( !proc.start( KProcess::DontCare ) )
+      KMessageBox::sorry( krApp, i18n( "Can't open " ) + "\"" + edit + "\"" );
+    return;
+  }
+
   KrViewer* viewer = new KrViewer(krApp);
 
   viewer->url = url;
@@ -206,6 +275,8 @@ bool KrViewer::editText( bool create ){
 
 bool KrViewer::viewGeneric(){
   QString mimetype = KMimeType::findByURL( url )->name();
+  // ugly hack: don't try to get a part for an XML file, it usually don't work
+  if( mimetype == "text/xml" ) return false;
   if( url.prettyURL().startsWith("man:") ) mimetype = "text/html";
   if( mimetype == "text/plain" )
     viewerMenu->setItemEnabled(1,false);
@@ -248,7 +319,7 @@ void KrViewer::viewHex(){
         KMessageBox::sorry(this,i18n("KrViewer is unable to download: ")+url.url());
         return;
       }
-    } else file = url.url().mid(url.url().find("/"));
+    } else file = url.path();
 
 
     // create a hex file
@@ -256,7 +327,7 @@ void KrViewer::viewHex(){
     f_in.open( IO_ReadOnly );
     QDataStream in( &f_in );
 
-    FILE *out = KDE_fopen(tmpFile.name().mid(tmpFile.name().find("/")).latin1(),"w");
+    FILE *out = KDE_fopen(tmpFile.name().local8Bit(),"w");
 
     KIO::filesize_t fileSize = f_in.size();
     KIO::filesize_t address = 0;
@@ -299,3 +370,27 @@ void KrViewer::handleOpenURLRequest( const KURL &url, const KParts::URLArgs & ){
   if(generic_part) generic_part->openURL(url);
 
 }
+
+bool KrViewer::queryClose()
+{
+  normalExit = true;
+  if( !editor_part || !editor_part->isModified() )
+    return true;
+
+  switch ( KMessageBox::warningYesNo( this, i18n("The Document has been changed. Do you want to quit, losing the modifications?")) )
+  {
+  case KMessageBox::Yes :
+    return true;
+  default:
+    return false;
+  }
+}
+
+bool KrViewer::queryExit()
+{
+  kapp->ref(); // FIX: krusader exits at closing the viewer when minimized to tray
+  return true; // don't let the reference counter reach zero
+}
+
+
+#include "krviewer.moc"
