@@ -50,6 +50,11 @@ public slots:
   void createGUI(KParts::Part*);
 
   void handleOpenURLRequest( const KURL &url, const KParts::URLArgs & );
+
+protected:
+  virtual bool queryClose();
+  virtual bool queryExit();
+
 private:
   KrViewer(QWidget *parent=0, const char *name=0);
   KParts::Part* getPart(KURL url, QString m ,bool readOnly, bool create=false);
@@ -64,6 +69,7 @@ private:
   KParts::ReadWritePart *editor_part;
 
   KTempFile tmpFile;
+  bool normalExit;
 };
 
 #endif
