@@ -34,7 +34,30 @@
 #include "../krusader.h"
 #include "../VFS/vfile.h"
 #include "../VFS/vfs.h"
-#include "krviewitem.h"
+
+#include <kdebug.h>
+
+// KrViewProperties
+// This class is an interface class between KrView and KrViewItem
+// In order for KrViewItem to be as independant as possible, KrView holds 
+// an instance of this class, and fills it with the correct data. A reference
+// to this should be given to each KrViewItem, which then queries it for 
+// information regarding how things should be displayed in the current view.
+//
+// Every property that the item needs to know about the view must be here!
+class KrViewProperties {
+public:
+	enum SortSpec { Name=0x1, Ext=0x2, Size=0x4, Type=0x8, Modified=0x10, Permissions=0x20,
+						KrPermissions=0x40, Owner=0x80, Group=0x100, Descending=0x200,
+						DirsFirst=0x400, IgnoreCase=0x800 };
+	enum FilterSpec { Dirs=0x1, Files=0x2, All=0x3, Custom=0x4, ApplyToDirs=0x8 };
+	
+	bool displayIcons;	// true if icons should be displayed in this view
+	SortSpec sortMode;	// sort specifications
+	FilterSpec filter;	// what items to show (all, custom, exec)
+  	QString filterMask;	// what items to show (*.cpp, *.h etc)
+};
+
 
 /****************************************************************************
  * READ THIS FIRST: Using the view
@@ -54,27 +77,13 @@
  *    to the current item (used in detailedview for safe iterating), thus your loop should be:
  *       for (KrViewItem *it = view->getFirst(); it!=0; it = view->getNext(it)) { blah; }
  * 5) nameToMakeCurrent(), setNameToMakeCurrent() - work with QString
+ *
+ * IMPORTANT NOTE: every one who subclasses this must call initProperties() in the constructor !!!
  */
-
-/////////////////////////////////////////////////////////////////
-// the following settings are available for ALL kinds of views
-//
-// With Icons
-#define _WithIcons          true
-// View Background
-#define _ViewBackground     new QColor("white")
-// Single Click Selects
-#define _SingleClickSelects false
-
+class KrViewItem;
+ 
 typedef QValueList<KrViewItem*> KrViewItemList;
 class KrView {
-public:
-  enum SortSpec { Name=0x1, Ext=0x2, Size=0x4, Type=0x8, Modified=0x10, Permissions=0x20,
-                  KrPermissions=0x40, Owner=0x80, Group=0x100, Descending=0x200,
-                  DirsFirst=0x400, IgnoreCase=0x800 };
-  enum FilterSpec { Dirs=0x1, Files=0x2, All=0x3, Custom=0x4, ApplyToDirs=0x8 };
-
-
 public:
   ///////////////////////////////////////////////////////
   // Every view must implement the following functions //
@@ -84,7 +93,11 @@ public:
   virtual KrViewItem *getPrev(KrViewItem *current) = 0;
   virtual KrViewItem *getCurrentKrViewItem() = 0;
   virtual KrViewItem *getKrViewItemAt(const QPoint &vp) = 0;
-  virtual void addItems(vfs* v, bool addUpDir = true) = 0;
+  virtual KrViewItem *findItemByName(const QString &name) = 0;
+  virtual void addItems(vfs* v, bool addUpDir = true) = 0; // kill me, kill me now
+  virtual void addItem(vfile *vf) = 0;
+  virtual void delItem(const QString &name) = 0;
+  virtual void updateItem(vfile *vf) = 0;
   virtual QString getCurrentItem() const = 0;
   virtual void setCurrentItem(const QString& name) = 0;
   virtual void makeItemVisible(const KrViewItem *item) = 0;
@@ -97,11 +110,16 @@ public:
   virtual void prepareForPassive() = 0;
   virtual QString nameInKConfig() = 0;
   virtual void renameCurrentItem() = 0; // Rename current item. returns immediatly
+protected:
+  virtual void initProperties() = 0;
+  
+public:  
   // also, the following must be implemented (but must be remarked here)
+  //
   // signals:
   //   void letsDrag(QStringList items, QPixmap icon);
   //   void gotDrop(QDropEvent *);
-  //   void selectionChanged();  
+  //   void selectionChanged();
 
   //////////////////////////////////////////////////////
   // the following functions are already implemented, //
@@ -114,50 +132,47 @@ public:
   virtual uint count() const { return _count; }
   virtual KIO::filesize_t countSize() const { return _countSize; }
   virtual void getSelectedItems(QStringList* names);
+  virtual void getItemsByMask(QString mask, QStringList* names, bool dirs = true, bool files = true);
   virtual void getSelectedKrViewItems(KrViewItemList *items);
+  virtual void selectAllIncludingDirs() { changeSelection("*", true, true); }
   virtual void select(const QString& filter = "*") { changeSelection(filter, true); }
   virtual void unselect(const QString& filter = "*") { changeSelection(filter, false); }
   virtual void invertSelection();
   virtual QString nameToMakeCurrent() const { return _nameToMakeCurrent; }
   virtual void setNameToMakeCurrent(const QString name) { _nameToMakeCurrent = name; }
-  virtual QString firstUnmarkedAboveCurrent();
+  virtual QString firstUnmarkedBelowCurrent();
   virtual QString statistics();
+  const KrViewProperties* properties() const { return _properties; }
 
   /////////////////////////////////////////////////////////////
   // the following functions have a default and minimalistic //
   // implementation, and may be re-implemented if needed     //
   /////////////////////////////////////////////////////////////
-  virtual void setSortMode(SortSpec mode) { _sortMode = mode; }
-  virtual SortSpec sortMode() const { return _sortMode; }
-  virtual void setFilter(FilterSpec filter) { _filter = filter; }
-  virtual FilterSpec filter() const { return _filter; }
-  virtual void setFilterMask(QString mask) { _filterMask = mask; }
-  virtual QString filterMask() const { return _filterMask; }
+  virtual void setSortMode(KrViewProperties::SortSpec mode) { _properties->sortMode = mode; }
+  virtual KrViewProperties::SortSpec sortMode() const { return _properties->sortMode; }
+  virtual void setFilter(KrViewProperties::FilterSpec filter) { _properties->filter = filter; }
+  virtual KrViewProperties::FilterSpec filter() const { return _properties->filter; }
+  virtual void setFilterMask(QString mask) { _properties->filterMask = mask; }
+  virtual QString filterMask() const { return _properties->filterMask; }
   inline QWidget *widget() { return _widget; }
   inline void setWidget(QWidget *w) { _widget = w; }
 
-  /////////////////remove/////////////////
-  virtual QString itemToFilename(QListViewItem *it) = 0;
-
-
   // todo: what about selection modes ???
-  virtual ~KrView() {}
+  virtual ~KrView();
 protected:
   KrView(KConfig *cfg = krConfig);
   static QPixmap getIcon(vfile *vf);
-  void changeSelection(const QString& filter, bool select);
+  void changeSelection(const QString& filter, bool select, bool includeDirs = false);
 
 
 protected:
   KConfig *_config;
-  SortSpec _sortMode;
-  FilterSpec _filter;
-  QString _filterMask;
   QWidget *_widget;
   QString _nameToMakeCurrent;
   uint _numSelected, _count, _numDirs;
   KIO::filesize_t _countSize, _selectedSize;
   bool _left;
+  KrViewProperties *_properties;
 };
 
 #endif /* KRVIEW_H */
