@@ -43,7 +43,7 @@
 #include <qstringlist.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 QString remoteMan::url=QString::null;
 
@@ -318,8 +318,8 @@ void remoteMan::connection() {
   }
   // build a url
   if (anonymous->isChecked()) {
-    userName->setText("anonymous");
-    password->setText("billg@microsoft.com");
+    userName->setText(QString::null);
+    password->setText(QString::null);
   } else {
     userName->setText(userName->text().simplifyWhiteSpace());
     password->setText(password->text().simplifyWhiteSpace());
@@ -336,6 +336,7 @@ void remoteMan::connection() {
 		port=":"+portNum->cleanText();
 
 	url=protocol->currentText();
+
 	if( !userName->text().isEmpty() ){
 		url = url+userName->text();
 		if( !password->text().isEmpty() );
