@@ -33,62 +33,84 @@
 #ifndef KRSEARCHDIALOG_H
 #define KRSEARCHDIALOG_H
 
-#include <qwidget.h>
-#include <qstringlist.h>
-#include <kshellcompletion.h>
-#include "krsearchdialogbase.h"
+#include "generalfilter.h"
+#include "advancedfilter.h"
 #include "krquery.h"
 #include "krsearchmod.h"
+#include "../GUI/profilemanager.h"
+
+#include <qwidget.h>
+#include <ksqueezedtextlabel.h>
+#include <qstringlist.h>
 #include <sys/types.h>
 #include <time.h>
+#include <qstring.h>
+#include <qtabwidget.h>
+#include <qlistview.h>
+#include <qstringlist.h>
 
-
-class KrSearchDialog : public KrSearchBase  {
+class KrSearchDialog : public QDialog  {
    Q_OBJECT
 public: 
-	KrSearchDialog(QWidget *parent=0, const char *name=0);
-	~KrSearchDialog();
-	
-	void prepareGUI();
-	
+  KrSearchDialog(QString profile = 0, QWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
+
+  void prepareGUI();
+    
 public slots:
-  void saveSearch();
-  void loadSearch();
-  void loadSearch(QListViewItem *);
   void startSearch();
   void stopSearch();
   void found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm);
-  void closeDialog();
-  void addToSearchIn();
-  void addToSearchInManually();
-  void addToDontSearchIn();
-  void addToDontSearchInManually();
-  void modifiedBetweenSetDate1();
-  void modifiedBetweenSetDate2();
-  void notModifiedAfterSetDate();
+  void closeDialog( bool isAccept = true );
   void resultClicked(QListViewItem*);
 
   virtual void keyPressEvent(QKeyEvent *e);
   virtual void closeEvent(QCloseEvent *e);
+  virtual void rightClickMenu(QListViewItem*, const QPoint&, int);
+  virtual void resizeEvent( QResizeEvent *e );
 
 protected slots:
   void reject();
 
 private:
-  void refreshSavedSearches();
-  void invalidDateMessage(QLineEdit *p);
-  void fillList(QComboBox *list, QString filename);
   bool gui2query();
-  void query2gui();
-  void deleteSelectedItems( QListBox * );
+  void editCurrent();
+  void viewCurrent();
 
 private:
+  GeneralFilter  *generalFilter;
+  AdvancedFilter *advancedFilter;
+  ProfileManager *profileManager;
+    
+  QPushButton* mainHelpBtn;
+  QPushButton* mainSearchBtn;
+  QPushButton* mainStopBtn;
+  QPushButton* mainCloseBtn;
+  
+  QTabWidget* searcherTabs;  
+  QWidget* resultTab;
+  QGridLayout* resultLayout;
+  QLabel* foundLabel;
+  KSqueezedTextLabel* searchingLabel;
+  
+  QListView* resultsList;
+
   KRQuery *query;
   KRSearchMod *searcher;
-  KShellCompletion completion;
   QStringList savedSearches;
   bool isSearching;
   bool closed;
+  
+  static QString lastSearchText;
+  static int     lastSearchType;
+  static bool    lastSearchForCase;
+  static bool    lastContainsWholeWord;
+  static bool    lastContainsWithCase;
+  static bool    lastSearchInSubDirs;
+  static bool    lastSearchInArchives;
+  static bool    lastFollowSymLinks;
+  
+  int            sizeX;
+  int            sizeY;
 };
 
 #endif
