@@ -47,7 +47,7 @@ public:
  ~arc_vfs();
 	
 	// copy a file to the vfs (physical)
-	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWidget* toNotify=0,QString dir = "");	
+	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify=0,QString dir = "");	
 	// remove a file from the vfs (physical)
 	void 		vfs_delFiles(QStringList *fileNames);	
 	// return a path to the file
@@ -58,14 +58,13 @@ public:
 	// rename file
 	void vfs_rename(QString fileName,QString newName);
 	// calculate space
-	void vfs_calcSpace(QString name ,long long *totalSize,long *totalFiles, long *totalDirs);
+	void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool* stop = 0);
 	// return the working dir
 	QString vfs_workingDir();
 	
 public slots:
 	// actually reads files and stats
 	bool vfs_refresh(QString origin);
-	inline  bool vfs_refresh(){return vfs_refresh(vfs_origin);}
   void repack();
 	
 protected:
@@ -75,7 +74,7 @@ protected:
   QList<arc_dir> dirList;
   QValueList<extFile> extFiles; // the name, time & size of files unpacked from this archive
 
-  void processName(const QString& name,QStringList *urls,unsigned long *totalSize,unsigned long *totalFiles );
+  void processName(const QString& name,QStringList *urls,KIO::filesize_t *totalSize,unsigned long *totalFiles );
   bool getDirs();   // fill the dir list
   QList<vfile>* findDir(QString name);
   arc_dir* findArcDir(QString name);
