@@ -27,10 +27,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifdef _OS_SOLARIS_
 #include <strings.h>
-#endif
-
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -55,105 +52,86 @@
 #include "../defaults.h"
 #include "../resources.h"
 
-normal_vfs::normal_vfs(QString,QWidget* panel):vfs(panel){
-  vfs_filesP = &vfs_files;
+normal_vfs::normal_vfs(QObject* panel):vfs(panel), watcher(0) {
+  setVfsFilesP(&vfs_files);
   vfs_files.setAutoDelete(true);
-	
-	vfs_type="normal";
-	
-	// connect the watcher to vfs_refresh
-  //connect(&watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_refresh()));
-  connect(&watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_slotDirty()));
+  
+  vfs_type=NORMAL;
 }
 
-bool normal_vfs::vfs_refresh(QString origin){
-	// check that the new origin exists
-	if ( !QDir(origin).exists() ) return false;
-    
-  krConfig->setGroup("Advanced");
-  if (krConfig->readBoolEntry("AutoMount",_AutoMount)) krMtMan.autoMount(origin);
-   	
-	watcher.stopScan(); //stop watching the old dir
-  if( origin != vfs_getOrigin() ){
-		watcher.removeDir(vfs_getOrigin()); // and remove it from the list
-		watcher.addDir(origin/*,true*/); //start watching the new dir
-	}
-	//watcher.clearList();
-
+bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
+	QString path = origin.path(-1);
+		
 	// set the writable attribute to true, if that's not the case - the KIO job
-  // will give the warnings and errors
+	// will give the warnings and errors
 	isWritable = true;
 	
- 	krConfig->setGroup("Look&Feel");
-	bool hidden = krConfig->readBoolEntry("Show Hidden",_ShowHidden);
+	if( watcher ) delete watcher; //stop watching the old dir
+	watcher = 0;
+
+	// set the origin...
+	vfs_origin = origin;
+	vfs_origin.setProtocol("file"); // do not remove !
+	vfs_origin.cleanPath();
+	
+	// check that the new origin exists
+	if ( !QDir(path).exists() )
+	{
+		if( !quietMode ) KMessageBox::error(krApp, i18n("Directory %1 does not exist!").arg( path ), i18n("Error"));
+		return false;
+	}
+    
+	krConfig->setGroup("Advanced");
+	if (krConfig->readBoolEntry("AutoMount",_AutoMount)) krMtMan.autoMount(path);
+	
 	krConfig->setGroup("General");
 	bool mtm    = krConfig->readBoolEntry("Mimetype Magic",_MimetypeMagic);
 
-	// set the origin...
-	if( vfs_type == "normal" ) vfs_origin = QDir::cleanDirPath(origin);
-  // clear the the list
-	vfs_files.clear();
-	
-	DIR* dir = opendir(origin.local8Bit());
-  if(!dir) return false;
+	DIR* dir = opendir(path.local8Bit());
+	if(!dir) 
+	{
+		if( !quietMode ) KMessageBox::error(krApp, i18n("Can't open the %1 directory!").arg( path ), i18n("Error"));
+		return false;
+	}
 
   // change directory to the new directory
-  chdir(origin.local8Bit());
-  
-	if (!quietMode) emit startUpdate();
-	
+	if (chdir(path.local8Bit()) != 0) {
+		if( !quietMode ) KMessageBox::error(krApp, i18n("Access denied to")+path, i18n("Error"));
+		closedir(dir);
+		return false;
+	}
+
 	struct dirent* dirEnt;
   QString name;
-	KURL mimeUrl;
-	//int i = 0;
-  char symDest[256];
-  KDE_struct_stat stat_p;
+
 	while( (dirEnt=readdir(dir)) != NULL ){
     name = QString::fromLocal8Bit(dirEnt->d_name);
 
 		// show hidden files ?
-		if ( !hidden && name.left(1) == "." ) continue ;
+		if ( !showHidden && name.left(1) == "." ) continue ;
 		// we dont need the ".",".." enteries
 		if (name=="." || name == "..") continue;
-	  	
-	  KDE_lstat(vfs_workingDir().local8Bit()+"/"+name.local8Bit(),&stat_p);
-	  KIO::filesize_t size = stat_p.st_size;
-    QString perm = KRpermHandler::mode2QString(stat_p.st_mode);
-	  bool symLink= S_ISLNK(stat_p.st_mode);
-	  if( S_ISDIR(stat_p.st_mode) ) perm[0] = 'd';
-	
-	  bzero(symDest,256);
-		mimeUrl.setPath(vfs_workingDir()+"/"+name);
-	  QString mime=KMimeType::findByURL( mimeUrl,stat_p.st_mode,true,!mtm)->name();
-	
-	  if( S_ISLNK(stat_p.st_mode) ){  // who the link is pointing to ?
-	    int endOfName=0;
-	    endOfName=readlink(vfs_workingDir().local8Bit()+"/"+name.local8Bit(),symDest,256);
-	    if ( endOfName != -1 ){
-	      if ( QDir(symDest).exists() || mime.contains("directory") ) perm[0] = 'd';
-	      //QString symTemp = (symDest[0]=='/' ? symDest : vfs_workingDir()+"/"+symDest);
-	      if ( !QDir(vfs_workingDir()).exists(symDest)  ) mime = "Broken Link !";
-      }
-      else kdWarning() << "Failed to read link: "<< vfs_workingDir()+"/"+name<<endl;
-	  }
-	  	
-	  // create a new virtual file object
-    vfile* temp=new vfile(name,size,perm,stat_p.st_mtime,symLink,stat_p.st_uid,
-                          stat_p.st_gid,mime,symDest,stat_p.st_mode);
-    vfs_addToList(temp);
+	  
+		vfile* temp = vfileFromName(name,mtm);
+    addToList(temp);
   }
 	// clean up
 	closedir(dir);
 	
-	if (!quietMode) emit endUpdate();
-  watcher.startScan();
+	watcher = new KDirWatch();
+	// connect the watcher
+  connect(watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_slotDirty(const QString&)));
+  connect(watcher,SIGNAL(created(const QString&)),this, SLOT(vfs_slotCreated(const QString&)));
+  connect(watcher,SIGNAL(deleted(const QString&)),this, SLOT(vfs_slotDeleted(const QString&)));	
+  watcher->addDir(vfs_getOrigin().path(-1),true); //start watching the new dir
+  watcher->startScan(true);
 
   return true;
 }
 
 // copy a file to the vfs (physical)	
 void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir){
-  watcher.stopScan(); // we will refresh manually this time...	
+  if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
 
 	KURL dest;
 	dest.setPath(vfs_workingDir()+"/"+dir);
@@ -171,7 +149,7 @@ void normal_vfs::vfs_delFiles(QStringList *fileNames){
 	QDir local( vfs_workingDir() );
   vfile* vf;
 
-  watcher.stopScan(); // we will refresh manually this time...	
+  if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
 
 	// names -> urls
 	for(uint i=0 ; i<fileNames->count(); ++i){
@@ -195,39 +173,39 @@ void normal_vfs::vfs_delFiles(QStringList *fileNames){
 }
 
 // return a path to the file
-QString normal_vfs::vfs_getFile(QString name){	
-	if ( vfs_workingDir() == "/" ) return ("/"+name);
-	else return ( vfs_workingDir()+"/"+name);
+KURL normal_vfs::vfs_getFile(const QString& name){	
+  QString url;
+	if ( vfs_workingDir() == "/" ) url = "/"+name;
+	else url = vfs_workingDir()+"/"+name;
+
+	return vfs::fromPathOrURL(url);
 }
 
 KURL::List* normal_vfs::vfs_getFiles(QStringList* names){
-  KURL url;
   KURL::List* urls = new KURL::List();
   for(QStringList::Iterator name = names->begin(); name != names->end(); ++name){
-    url.setPath( vfs_getFile(*name) );
-    urls->append(url);
+    urls->append( vfs_getFile(*name) );
   }
   return urls;
 }
 
-void normal_vfs::vfs_mkdir(QString name){
+void normal_vfs::vfs_mkdir(const QString& name){
 	if (!QDir(vfs_workingDir()).mkdir(name))
 	  if (!quietMode) KMessageBox::sorry(krApp,i18n("Can't create a directory check your permissions."));
-  vfs_refresh(vfs_origin);
+  vfs::vfs_refresh();
 }
 
-
-void normal_vfs::vfs_rename(QString fileName,QString newName){
+void normal_vfs::vfs_rename(const QString& fileName,const QString& newName){
   KURL::List fileUrls;
   KURL url , dest;
 
-  watcher.stopScan(); // we will refresh manually this time...	
+  if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
 
   url.setPath( vfs_workingDir()+"/"+fileName );
   fileUrls.append(url);
 	dest.setPath(vfs_workingDir()+"/"+newName);
 
-  KIO::Job *job = new KIO::CopyJob(fileUrls,dest,KIO::CopyJob::Move,false,false );
+  KIO::Job *job = new KIO::CopyJob(fileUrls,dest,KIO::CopyJob::Move,true,false );
 	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 }
 
@@ -259,4 +237,108 @@ void normal_vfs::vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned
   }
 }
 
+vfile* normal_vfs::vfileFromName(const QString& name,bool mimeTypeMagic){
+	QString path = vfs_workingDir()+"/"+name;
+	
+	KDE_struct_stat stat_p;
+	KDE_lstat(path.local8Bit(),&stat_p);
+	KIO::filesize_t size = stat_p.st_size;
+	QString perm = KRpermHandler::mode2QString(stat_p.st_mode);
+	bool symLink= S_ISLNK(stat_p.st_mode);
+	if( S_ISDIR(stat_p.st_mode) ) perm[0] = 'd';
+	
+	KURL mimeUrl = fromPathOrURL(path);
+	QString mime=KMimeType::findByURL( mimeUrl,stat_p.st_mode,true,!mimeTypeMagic)->name();
+
+	char symDest[256];
+	bzero(symDest,256); 
+	if( S_ISLNK(stat_p.st_mode) ){  // who the link is pointing to ?
+		int endOfName=0;
+		endOfName=readlink(path.local8Bit(),symDest,256);
+		if ( endOfName != -1 ){
+			if ( QDir(QString::fromLocal8Bit( symDest ) ).exists() || mime.contains("directory") ) perm[0] = 'd';
+			if ( !QDir(vfs_workingDir()).exists( QString::fromLocal8Bit ( symDest ) ) ) mime = "Broken Link !";
+		}
+		else kdWarning() << "Failed to read link: "<< path<<endl;
+	}
+	
+	// create a new virtual file object
+	vfile* temp=new vfile(name,size,perm,stat_p.st_mtime,symLink,stat_p.st_uid,
+                          stat_p.st_gid,mime,symDest,stat_p.st_mode);
+	return temp;
+}
+
+void normal_vfs::vfs_slotRefresh()
+{
+	krConfig->setGroup("Advanced");
+	int maxRefreshFrequency = krConfig->readNumEntry("Max Refresh Frequency", 1000);
+	vfs_refresh();
+	disconnect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
+	refreshTimer.start( maxRefreshFrequency, true );
+}
+
+void normal_vfs::vfs_slotDirty(const QString& path){ 
+	if( disableRefresh ){
+		dirty = true;
+		return;
+	}
+	
+	if( path == vfs_getOrigin().path(-1) ){
+		if( !refreshTimer.isActive() ) {
+			// the directory itself is dirty - full refresh is needed
+			QTimer::singleShot(0, this, SLOT( vfs_slotRefresh() ) ); // safety: dirty signal comes from KDirWatch!
+			return;
+		}
+		disconnect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
+		connect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
+		dirty = true;
+		return;                
+	}
+	
+	KURL url = fromPathOrURL(path);
+	QString name = url.fileName();
+	
+	// do we have it already ?
+	if( !vfs_search(name ) ) return vfs_slotCreated(path);
+	
+	// we have an updated file..
+	removeFromList(name);
+	vfile* vf = vfileFromName(name,true);
+	addToList(vf);
+	emit updatedVfile(vf);
+}
+
+void normal_vfs::vfs_slotCreated(const QString& path){  
+	if( disableRefresh ){
+		dirty = true;
+		return;
+	}	
+	
+	KURL url = fromPathOrURL(path);
+	QString name = url.fileName();	
+	// if it's in the CVS - it's an update not new file
+	if( vfs_search(name) )
+		return vfs_slotDirty(path);
+	
+	vfile* vf = vfileFromName(name,true);
+	addToList(vf);
+	emit addedVfile(vf);	
+}
+
+void normal_vfs::vfs_slotDeleted(const QString& path){ 
+	if( disableRefresh ){
+		dirty = true;
+		return;
+	}
+	
+	KURL url = fromPathOrURL(path);
+	QString name = url.fileName();
+	
+	// if it's not in the CVS - do nothing
+	if( vfs_search(name) ){
+		emit deletedVfile(name);
+		removeFromList(name);	
+	}	
+}
+
 #include "normal_vfs.moc"
