@@ -19,6 +19,8 @@
 #define KRSERVICES_H
 
 #include <qstring.h>
+#include <qstringlist.h>
+#include <qmap.h>
 
 /**
   *@author Shie Erlich & Rafi Yanai
@@ -29,7 +31,16 @@ public:
 	KrServices(){}
 	~KrServices(){}
 
-	static bool cmdExist(QString cmdName);
+	static bool         cmdExist(QString cmdName);
+	static QString      detectFullPathName( QString name );
+	static QString      fullPathName( QString name, QString confName = QString::null );
+	static QStringList  separateArgs( QString args );
+	static QString      registerdProtocol(QString mimetype);
+	static void         clearProtocolCache();
+
+private:
+	static QMap<QString,QString>* slaveMap;
+
 };
 
 #endif
