@@ -38,33 +38,33 @@
 #include "krusader.h"
 #include "krusaderview.h"
 #include "Panel/listpanel.h"
-#include "BookMan/bookmarksbutton.h"
+#include "Panel/panelfunc.h"
+#include "BookMan/krbookmarkbutton.h"
 #include "GUI/kcmdline.h"
+#include "GUI/dirhistorybutton.h"
 
 class ListPanel;
+class KURL;
 
 class KRslots : public QObject {
     Q_OBJECT
 
-  private:
-    bool panel_swap;
-    
   public:
     enum compareMode { full } ;
 
-    KRslots() {panel_swap = false;}
+    KRslots() {}
     ~KRslots() {}
 
   public slots:
-    void selectCompareMask();
-    void compareDirectories();
     void sendFileByEmail( QString filename );
     void compareContent();
+    void compareContent( KURL, KURL );
     void rightclickMenu();
     void insertFileName(bool full_path);
     void rootKrusader();
     void toggleHidden();
     void toggleSwapPanels();
+	 void togglePopupPanel();
     void configToolbar();
     void configKeys();
     void toggleToolbar();
@@ -76,14 +76,20 @@ class KRslots : public QObject {
     void markAll();
     void unmarkAll();
     void markGroup();
+	 void markGroup(const QString &, bool select);
     void unmarkGroup();
     void invert();
+    void compareDirs();
+    void compareSetup();
     void refresh();
-    void refresh( QString p );
+    void refresh( const KURL& u );
     void properties();
     void back();
     void slotPack();
     void slotUnpack();
+    void cut();
+    void copy();
+    void paste();
     void testArchive();
     void calcSpace();
     void FTPDisconnect();
@@ -91,10 +97,10 @@ class KRslots : public QObject {
     void execFilter();
     void customFilter();
     void newFTPconnection();
-    void newFTPconnection( QString host );
     void runKonfigurator( bool firstTime = false );
     void startKonfigurator() { runKonfigurator( false ); }
     void search();						 				// call the search module
+    void locate();
     void homeTerminal();
     void sysInfo();
     void addBookmark();
@@ -105,14 +111,31 @@ class KRslots : public QObject {
     void changeTrashIcon();
     void showAboutApplication();
     void multiRename();
-    void openRightBookmarks() { krApp->mainView->right->bookmarksButton->openPopup(); }
-    void openLeftBookmarks() { krApp->mainView->left->bookmarksButton->openPopup(); }
-    void cmdlinePopup() { krApp->mainView->cmdLine->popup(); }
+    void openRightBookmarks() { RIGHT_PANEL->slotFocusOnMe(); RIGHT_PANEL->bookmarksButton->openPopup(); }
+    void openLeftBookmarks() { LEFT_PANEL->slotFocusOnMe(); LEFT_PANEL->bookmarksButton->openPopup(); }
+	 void openBookmarks() { ACTIVE_PANEL->bookmarksButton->openPopup(); }	
+    void openLeftHistory() { LEFT_PANEL->historyButton->openPopup(); }
+    void openRightHistory() { RIGHT_PANEL->historyButton->openPopup(); }
+	 void syncPanels() {
+	 	ListPanel *t = ACTIVE_PANEL;
+		OTHER_FUNC->openUrl(ACTIVE_PANEL->virtualPath);
+		t->slotFocusOnMe();
+	 }
+    void cmdlinePopup() { MAIN_VIEW->cmdLine->popup(); }
     void duplicateTab();
     void newTab();
     void newTab(QListViewItem *item);
     void closeTab();
-    
+    void nextTab();
+    void previousTab();
+    void slotSplit();
+    void slotCombine();
+    void userMenu();
+    void slotSynchronizeDirs();
+    void slotDiskUsage();
+    void updatePopupPanel(QListViewItem*);
+		void windowActive(); // called when krusader's window becomes focussed
+		void windowInactive(); // called when another application steals the focus
     // F2
     void terminal();
     // F3
@@ -135,8 +158,8 @@ class KRslots : public QObject {
     void rename();
 
     // ugly stubs, remove later ?
-    void slotCurrentChanged( QString p ) { krApp->mainView->slotCurrentChanged( p ); }
-    void slotSetActivePanel( ListPanel *p ) { krApp->mainView->slotSetActivePanel( p ); }
+    void slotCurrentChanged( QString p ) { MAIN_VIEW->slotCurrentChanged( p ); }
+    void slotSetActivePanel( ListPanel *p ) { MAIN_VIEW->slotSetActivePanel( p ); }
 };
 
 #endif
