@@ -9,9 +9,9 @@
  ---------------------------------------------------------------------------
  The main application ! what's more to say ?
  ***************************************************************************
- 
+
   A
- 
+
      db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
      88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
      88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
@@ -45,7 +45,6 @@
 #include <kconfig.h>
 #include <kaccel.h>
 #include <qstringlist.h>
-#include "MountMan/kmountman.h"
 
 class KrusaderStatus;
 class KRPleaseWaitHandler;
@@ -54,6 +53,11 @@ class KProcess;
 class KRslots;
 class KIconLoader;
 class KSystemTray;
+class UserMenu;
+class UserAction;
+class Expander;
+class KMountMan;
+class KrBookmarkHandler;
 
 class Krusader : public KParts::MainWindow {
     Q_OBJECT
@@ -84,26 +88,34 @@ class Krusader : public KParts::MainWindow {
     bool versionControl();  // handle version differences in krusaderrc
     void showEvent ( QShowEvent * );
     void hideEvent ( QHideEvent * );
+    void moveEvent ( QMoveEvent * );
+    void resizeEvent ( QResizeEvent * );
 
   public:
     static Krusader *App;       // a kApp style pointer
-    MountMan::KMountMan *mountMan;  // krusader's Mount Manager
+    KMountMan *mountMan;  // krusader's Mount Manager
     KrusaderView *mainView;  // The GUI
     KConfig *config;    // allow everyone to access the config
     KIconLoader *iconLoader; // the app's icon loader
     // Actions
     static KAction *actProperties, *actPack, *actUnpack, *actTest, *actCompare, *actCmdlinePopup;
-    static KAction *actCalculate, *actSelect, *actUnselect, *actSelectAll;
-    static KAction *actUnselectAll, *actInvert, *actSync, *actSavePosition;
-    static KAction *actHomeTerminal, *actFTPConnect, *actFTPNewConnect, *actFTPDisconnect;
-    static KAction *actExecFilter, *actCustomFilter, *actMountMan, *actNewTool;
+    static KAction *actCalculate, *actSelect, *actUnselect, *actSelectAll, *actLocate;
+    static KAction *actUnselectAll, *actInvert, *actSync, *actDiskUsage, *actSavePosition, *actCompDirs;
+    static KAction *actHomeTerminal, *actFTPConnect, *actFTPNewConnect, *actFTPDisconnect, *actProfiles;
+    static KAction *actExecFilter, *actCustomFilter, *actMountMan, *actNewTool, *actSwapPanels;
     static KAction *actKonfigurator, *actToolsSetup, *actBack, *actRoot, *actFind, *actDirUp;
     static KAction *actSelectColorMask, *actMultiRename, *actAllFilter, *actOpenLeftBm, *actOpenRightBm;
-    static KAction *actNewTab, *actDupTab, *actCloseTab;
+    static KAction *actNewTab, *actDupTab, *actCloseTab, *actPreviousTab, *actNextTab, *actSplit; 
+	 static KAction *actCombine, *actUserMenu, *actSyncDirs;
+	 static KAction *actF2, *actF3, *actF4, *actF5, *actF6, *actF7, *actF8, *actF9, *actF10;
     static KToggleAction *actToggleTerminal;
-    KToggleAction *actToggleFnkeys, *actToggleCmdline, *actShowToolBar, *actToggleSwapPanels,
+    static KRadioAction *actMarkNewerAndSingle, *actMarkNewer, *actMarkSingle, 
+                        *actMarkDifferentAndSingle, *actMarkDifferent;
+    KToggleAction *actToggleFnkeys, *actToggleCmdline, *actShowToolBar,
                   *actShowStatusBar, *actToggleHidden, *actCompareDirs;
 
+    static KRadioAction **compareArray[];
+
     // return a path to a temp dir or file we can use.
     QString getTempDir();
     QString getTempFile();
@@ -116,27 +128,45 @@ class Krusader : public KParts::MainWindow {
     KrusaderStatus *status;
     KRslots *slot;
     KAccel *accels; // global accelerators
+    static UserMenu *userMenu;
+    static UserAction *userAction;
+    static Expander *expander;
+	 static KrBookmarkHandler *bookman;
 
   signals:
     void changeMessage( QString );
 
   private:
     KSystemTray *sysTray;
+    QPoint       oldPos;
+    QSize        oldSize;
+    bool         isStarting;
 };
 
 // main modules
 #define krApp        Krusader::App
 #define krConfig     Krusader::App->config
 #define krMtMan      (*(Krusader::App->mountMan))
+#define krBookMan    Krusader::App->bookman
 #define SLOTS        Krusader::App->slot
 #define krLoader     Krusader::App->iconLoader
+
+#define MAIN_VIEW    (krApp->mainView)
+#define ACTIVE_PANEL (MAIN_VIEW->activePanel)
+#define ACTIVE_FUNC  (ACTIVE_PANEL->func)
+#define OTHER_PANEL	(ACTIVE_PANEL->otherPanel)
+#define OTHER_FUNC	(OTHER_PANEL->func)
+#define LEFT_PANEL	(MAIN_VIEW->left)
+#define LEFT_FUNC		(LEFT_PANEL->func)
+#define RIGHT_PANEL  (MAIN_VIEW->right)
+#define RIGHT_FUNC	(RIGHT_PANEL->func)
+
 // krusader's actions - things krusader can do!
 #define krProperties      Krusader::App->actProperties     // file properties
 #define krPack            Krusader::App->actPack           // pack files into an archive
 #define krUnpack          Krusader::App->actUnpack         // unpack archive
 #define krTest            Krusader::App->actTest           // test archive
 #define krCompare         Krusader::App->actCompare        // compare 2 files by content
-#define krCompareDirs     Krusader::App->actCompareDirs    // compare 2 directories
 #define krCalculate       Krusader::App->actCalculate      // calculate occupied space
 #define krSelect          Krusader::App->actSelect         // select a group by filter
 #define krSelectAll       Krusader::App->actSelectAll      // select all files
@@ -159,7 +189,6 @@ class Krusader : public KParts::MainWindow {
 #define krRoot            Krusader::App->actRoot
 #define krFind            Krusader::App->actFind           // find files
 #define krMultiRename     Krusader::App->actMultiRename
-#define krSelectColorMask Krusader::App->actSelectColorMask// select compare-mask
 #define krToggleTerminal  Krusader::App->actToggleTerminal
 #define krToggleSortByExt Krusader::App->actToggleSortByExt// Sort by extention
 #define krOpenLeftBm      Krusader::App->actOpenLeftBm     // open left bookmarks
@@ -169,5 +198,21 @@ class Krusader : public KParts::MainWindow {
 #define krNewTab          Krusader::App->actNewTab
 #define krDupTab          Krusader::App->actDupTab
 #define krCloseTab        Krusader::App->actCloseTab
+#define krNextTab         Krusader::App->actNextTab
+#define krPreviousTab     Krusader::App->actPreviousTab
+#define krSplit           Krusader::App->actSplit
+#define krCombine         Krusader::App->actCombine
+#define krUserMenu        Krusader::App->actUserMenu
+#define krUserAction      Krusader::App->userAction
+#define krExpander        Krusader::App->expander
+#define krF2				  Krusader::App->actF2
+#define krF3				  Krusader::App->actF3
+#define krF4				  Krusader::App->actF4
+#define krF5				  Krusader::App->actF5
+#define krF6				  Krusader::App->actF6
+#define krF7				  Krusader::App->actF7
+#define krF8				  Krusader::App->actF8
+#define krF9				  Krusader::App->actF9
+#define krF10				  Krusader::App->actF10
 
 #endif
