@@ -71,6 +71,11 @@ public slots:
 	//////////////////////////////////////////////
   // Tab - switch focus
   void panelSwitch();
+  void toggleVerticalMode();
+  
+  void profiles( QString profileName = QString::null );  
+  void loadPanelProfiles( QString group );
+  void savePanelProfiles( QString group );
 
 protected slots:
   void killTerminalEmulator();
